# Table of Contents

- [obsolescence-risk-management-enrich-data](<./obsolescence-risk-management-enrich-data.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 2: Enrich Data](<./Step-2-Enrich-Data.md>)
  - [Evaluate Business Criticality and Functional Fit](<./Step-2-Enrich-Data/Evaluate-Business-Criticality-and-Functional-Fit.md>)
  - [Link IT Components to the Reference Catalog](<./Step-2-Enrich-Data/Link-IT-Components-to-the-Reference-Catalog.md>)
  - [Monitor Data Completeness](<./Step-2-Enrich-Data/Monitor-Data-Completeness.md>)
  - [Next Step](<./Step-2-Enrich-Data/Next-Step.md>)
  - [Was this page helpful?](<./Step-2-Enrich-Data/Was-this-page-helpful.md>)
